@@ -1,14 +1,14 @@
 from collections.abc import Mapping, Sequence
-from contextlib import contextmanager
+
 from dataclasses import dataclass, field, replace
-from enum import Enum
+
 from functools import wraps
 import inspect
-from itertools import chain
+
 import os
-from operator import itemgetter
+
 import platform
-import re
+
 import shutil
 import sys
 import threading
@@ -22,21 +22,15 @@ from typing import (
     List,
     Optional,
     NamedTuple,
-    overload,
-    Tuple,
-    TYPE_CHECKING,
     Union,
 )
 from typing_extensions import Protocol, runtime_checkable, Literal
 
-
 from ._emoji_replace import _emoji_replace
-
 from .align import Align, AlignValues
 from .markup import render as render_markup
 from .measure import measure_renderables, Measurement
 from ._log_render import LogRender
-from .default_styles import DEFAULT_STYLES
 from . import errors
 from .color import ColorSystem
 from .control import Control
@@ -44,16 +38,12 @@ from .highlighter import NullHighlighter, ReprHighlighter
 from .pretty import Pretty
 from .style import Style
 from .tabulate import tabulate_mapping
-from . import highlighter
 from . import themes
-from .pretty import Pretty
 from .terminal_theme import TerminalTheme, DEFAULT_TERMINAL_THEME
 from .segment import Segment
-from .text import Text
+from .text import Text, TextType
 from .theme import Theme
 
-if TYPE_CHECKING:  # pragma: no cover
-    from .text import Text
 
 WINDOWS = platform.system() == "Windows"
 
@@ -151,10 +141,10 @@ _null_highlighter = NullHighlighter()
 
 class RenderGroup:
     """Takes a group of renderables and returns a renderable object that renders the group.
-                
+
     Args:
         renderables (Iterable[RenderableType]): An iterable of renderable objects.
-        
+
     """
 
     def __init__(self, *renderables: RenderableType, fit: bool = True) -> None:
@@ -201,7 +191,7 @@ class ConsoleDimensions(NamedTuple):
     height: int
 
 
-def _is_jupyter() -> bool:
+def _is_jupyter() -> bool:  # pragma: no cover
     """Check if we're running in a Jupyter notebook."""
     try:
         get_ipython  # type: ignore
@@ -285,7 +275,8 @@ class Console:
         log_time (bool, optional): Boolean to enable logging of time by :meth:`log` methods. Defaults to True.
         log_path (bool, optional): Boolean to enable the logging of the caller by :meth:`log`. Defaults to True.
         log_time_format (str, optional): Log time format if ``log_time`` is enabled. Defaults to "[%X] ".
-        highlighter(HighlighterType, optional): Default highlighter.    
+        highlighter (HighlighterType, optional): Default highlighter.
+        legacy_windows (bool, optional): Enable legacy Windows mode, or ``None`` to auto detect. Defaults to ``None``.
     """
 
     def __init__(
@@ -309,6 +300,7 @@ class Console:
         log_path: bool = True,
         log_time_format: str = "[%X]",
         highlighter: Optional["HighlighterType"] = ReprHighlighter(),
+        legacy_windows: bool = None,
     ):
         self.is_jupyter = force_jupyter or _is_jupyter()
         if self.is_jupyter:
@@ -322,7 +314,11 @@ class Console:
         self._markup = markup
         self._emoji = emoji
         self._highlight = highlight
-        self.legacy_windows: bool = detect_legacy_windows()
+        self.legacy_windows: bool = (
+            (detect_legacy_windows() and not self.is_jupyter)
+            if legacy_windows is None
+            else legacy_windows
+        )
 
         self._color_system: Optional[ColorSystem]
         self._force_terminal = force_terminal
@@ -655,7 +651,7 @@ class Console:
 
         try:
             style = self._styles.get(name)
-            return style if style is not None else Style.parse(name)
+            return style.copy() if style is not None else Style.parse(name).copy()
         except errors.StyleSyntaxError as error:
             if default is not None:
                 return self.get_style(default)
@@ -890,6 +886,11 @@ class Console:
             )
 
             caller = inspect.stack()[_stack_offset]
+            link_path = (
+                None
+                if caller.filename.startswith("<")
+                else os.path.abspath(caller.filename)
+            )
             path = caller.filename.rpartition(os.sep)[-1]
             line_no = caller.lineno
             if log_locals:
@@ -902,7 +903,7 @@ class Console:
 
             renderables = [
                 self._log_render(
-                    self, renderables, path=path, line_no=line_no, link_path=path
+                    self, renderables, path=path, line_no=line_no, link_path=link_path,
                 )
             ]
             for hook in self._render_hooks:
@@ -926,13 +927,14 @@ class Console:
                     text = self._render_buffer()
                     if text:
                         self.file.write(text)
-                    self.file.flush()
+                        self.file.flush()
 
     def _render_buffer(self) -> str:
         """Render buffered output, and clear buffer."""
         output: List[str] = []
         append = output.append
         color_system = self._color_system
+        legacy_windows = self.legacy_windows
         buffer = self._buffer[:]
         if self.record:
             with self._record_buffer_lock:
@@ -942,7 +944,13 @@ class Console:
         for line in Segment.split_and_crop_lines(buffer, self.width, pad=False):
             for text, style, is_control in line:
                 if style and not is_control:
-                    append(style.render(text, color_system=color_system))
+                    append(
+                        style.render(
+                            text,
+                            color_system=color_system,
+                            legacy_windows=legacy_windows,
+                        )
+                    )
                 else:
                     if not (not_terminal and is_control):
                         append(text)
@@ -951,12 +959,12 @@ class Console:
         return rendered
 
     def input(
-        self, prompt: Union[str, Text] = "", *, markup: bool = True, emoji: bool = True
+        self, prompt: TextType = "", *, markup: bool = True, emoji: bool = True
     ) -> str:
         """Displays a prompt and waits for input from the user. The prompt may contain color / style. 
 
         Args:
-            prompt (Union[Str, Text]): Text to render in the prompt.
+            prompt (Union[str, Text]): Text to render in the prompt.
             markup (bool, optional): Enable console markup (requires a str prompt). Defaults to True.
             emoji (bool, optional): Enable emoji (requires a str prompt). Defaults to True.
         
