@@ -1,18 +1,16 @@
 from abc import ABC, abstractmethod
 from collections import deque
 from collections.abc import Sized
-from contextlib import contextmanager
-from dataclasses import dataclass, replace, field
+from dataclasses import dataclass, field
 from datetime import timedelta
 import io
-from math import ceil, floor
+from math import ceil
 import sys
 from time import monotonic
 from threading import Event, RLock, Thread
 from typing import (
     Any,
     Callable,
-    cast,
     Deque,
     Dict,
     Iterable,
@@ -41,7 +39,7 @@ from .control import Control
 from .highlighter import Highlighter
 from . import filesize
 from .live_render import LiveRender
-from .style import Style, StyleType
+from .style import StyleType
 from .table import Table
 from .text import Text
 
@@ -796,16 +794,16 @@ if __name__ == "__main__":  # pragma: no coverage
 
     syntax = Syntax(
         '''def loop_last(values: Iterable[T]) -> Iterable[Tuple[bool, T]]:
-"""Iterate and generate a tup`le with a flag for last value."""
-iter_values = iter(values)
-try:
-    previous_value = next(iter_values)
-except StopIteration:
-    return
-for value in iter_values:
-    yield False, previous_value
-    previous_value = value
-yield True, previous_value''',
+    """Iterate and generate a tup`le with a flag for last value."""
+    iter_values = iter(values)
+    try:
+        previous_value = next(iter_values)
+    except StopIteration:
+        return
+    for value in iter_values:
+        yield False, previous_value
+        previous_value = value
+    yield True, previous_value''',
         "python",
         line_numbers=True,
     )
@@ -834,7 +832,7 @@ yield True, previous_value''',
 
         task1 = progress.add_task(" [red]Downloading", total=1000)
         task2 = progress.add_task(" [green]Processing", total=1000)
-        task3 = progress.add_task(" [yellow]Thinking", total=1000, start=False)
+        # task3 = progress.add_task(" [yellow]Thinking", total=1000, start=False)
 
         while not progress.finished:
             progress.update(task1, advance=0.5)
