@@ -1,7 +1,7 @@
 from typing import NamedTuple, Optional
 
 from .cells import cell_len, set_cell_size
-from .style import Style, StyleType
+from .style import Style
 
 from itertools import filterfalse, zip_longest
 from operator import attrgetter
@@ -70,7 +70,7 @@ class Segment(NamedTuple):
 
     @classmethod
     def filter_control(
-        self, segments: Iterable["Segment"], is_control=False
+        cls, segments: Iterable["Segment"], is_control=False
     ) -> Iterable["Segment"]:
         """Filter segments by ``is_control`` attribute.
 
