@@ -1,12 +1,12 @@
-from binascii import crc32
-from functools import lru_cache, reduce
-from operator import or_
 import sys
-from typing import Any, Dict, Iterable, List, Mapping, Optional, Type, Union
+from functools import lru_cache
+from random import randint
+from time import time
+from typing import Any, Dict, Iterable, List, Optional, Type, Union
 
 from . import errors
-from .color import blend_rgb, Color, ColorParseError, ColorSystem
-from .terminal_theme import TerminalTheme, DEFAULT_TERMINAL_THEME
+from .color import Color, ColorParseError, ColorSystem, blend_rgb
+from .terminal_theme import DEFAULT_TERMINAL_THEME, TerminalTheme
 
 # Style instances and style definitions are often interchangable
 StyleType = Union[str, "Style"]
@@ -64,6 +64,7 @@ class Style:
         "_attributes",
         "_set_attributes",
         "_link",
+        "_link_id",
         "_ansi",
         "_style_definition",
     ]
@@ -148,6 +149,7 @@ class Style:
             )
         )
         self._link = link
+        self._link_id = f"{time()}-{randint(0, 999999)}" if link else ""
 
     bold = _Bit(0)
     dim = _Bit(1)
@@ -163,6 +165,11 @@ class Style:
     encircle = _Bit(11)
     overline = _Bit(12)
 
+    @property
+    def link_id(self) -> str:
+        """Get a link id, used in ansi code for links."""
+        return self._link_id
+
     def __str__(self) -> str:
         """Re-generate style definition from attributes."""
         if self._style_definition is None:
@@ -278,7 +285,7 @@ class Style:
 
     def __repr__(self) -> str:
         """Render a named style differently from an anonymous style."""
-        return f'<style "{self}">'
+        return f'Style.parse("{self}")'
 
     def __eq__(self, other: Any) -> bool:
         if not isinstance(other, Style):
@@ -476,6 +483,7 @@ class Style:
         style._attributes = self._attributes
         style._set_attributes = self._set_attributes
         style._link = self._link
+        style._link_id = f"{time()}-{randint(0, 999999)}" if self._link else ""
         return style
 
     def render(
@@ -483,6 +491,7 @@ class Style:
         text: str = "",
         *,
         color_system: Optional[ColorSystem] = ColorSystem.TRUECOLOR,
+        legacy_windows: bool = False,
     ) -> str:
         """Render the ANSI codes for the style.
         
@@ -497,8 +506,11 @@ class Style:
             return text
         attrs = self._make_ansi_codes(color_system)
         rendered = f"\x1b[{attrs}m{text}\x1b[0m" if attrs else text
-        if self._link:
-            rendered = f"\x1b]8;id={crc32(self._link.encode('utf-8'))};{self._link}\x1b\\{rendered}\x1b]8;;\x1b\\"
+        if self._link and not legacy_windows:
+            rendered = (
+                f"\x1b]8;id={self._link_id};{self._link}\x1b\\{rendered}\x1b]8;;\x1b\\"
+            )
+
         return rendered
 
     def test(self, text: Optional[str] = None) -> None:
@@ -530,6 +542,7 @@ class Style:
         )
         new_style._set_attributes = self._set_attributes | style._set_attributes
         new_style._link = style._link or self._link
+        new_style._link_id = style._link_id or self._link_id
         return new_style
 
 
