@@ -1,21 +1,17 @@
 from dataclasses import dataclass, field
-from itertools import chain
 from typing import (
     TYPE_CHECKING,
     Iterable,
     List,
     NamedTuple,
     Optional,
-    Sequence,
     Tuple,
-    TypeVar,
     Union,
 )
 
-from typing_extensions import Literal
 
 from . import box, errors
-from ._loop import loop_first, loop_first_last, loop_last
+from ._loop import loop_first_last, loop_last
 from ._ratio import ratio_distribute, ratio_reduce
 from .jupyter import JupyterMixin
 from .measure import Measurement
@@ -23,7 +19,8 @@ from .padding import Padding, PaddingDimensions
 from .protocol import is_renderable
 from .segment import Segment
 from .style import Style, StyleType
-from .text import Text
+from .styled import Styled
+from .text import Text, TextType
 
 if TYPE_CHECKING:
     from .console import (
@@ -34,7 +31,6 @@ if TYPE_CHECKING:
         RenderableType,
         RenderResult,
     )
-    from .containers import Lines
 
 
 @dataclass
@@ -101,11 +97,12 @@ class Table(JupyterMixin):
         title (Union[str, Text], optional): The title of the table rendered at the top. Defaults to None.
         caption (Union[str, Text], optional): The table caption rendered below. Defaults to None.
         width (int, optional): The width in characters of the table, or ``None`` to automatically fit. Defaults to None.
-        box (Optional[box.Box], optional): One of the constants in box.py used to draw the edges (See :ref:`appendix_box`). Defaults to box.HEAVY_HEAD.
+        box (box.Box, optional): One of the constants in box.py used to draw the edges (see :ref:`appendix_box`). Defaults to box.HEAVY_HEAD.
+        safe_box (bool, optional): Disable box characters that don't display on windows legacy terminal with *raster* fonts. Defaults to True.
         padding (PaddingDimensions, optional): Padding for cells (top, right, bottom, left). Defaults to (0, 1).
         collapse_padding (bool, optional): Enable collapsing of padding around cells. Defaults to False.
         pad_edge (bool, optional): Enable padding of edge cells. Defaults to True.
-        expand (bool, optional): Expand the table to fit the available space if ``True`` otherwise the table width will be auto-calculated. Defaults to False.
+        expand (bool, optional): Expand the table to fit the available space if ``True``, otherwise the table width will be auto-calculated. Defaults to False.
         show_header (bool, optional): Show a header row. Defaults to True.
         show_footer (bool, optional): Show a footer row. Defaults to False.
         show_edge (bool, optional): Draw a box around the outside of the table. Defaults to True.
@@ -124,10 +121,11 @@ class Table(JupyterMixin):
     def __init__(
         self,
         *headers: Union[Column, str],
-        title: Union[str, Text] = None,
-        caption: Union[str, Text] = None,
+        title: TextType = None,
+        caption: TextType = None,
         width: int = None,
         box: Optional[box.Box] = box.HEAVY_HEAD,
+        safe_box: bool = True,
         padding: PaddingDimensions = (0, 1),
         collapse_padding: bool = False,
         pad_edge: bool = True,
@@ -153,9 +151,10 @@ class Table(JupyterMixin):
         self.caption = caption
         self.width = width
         self.box = box
+        self.safe_box = safe_box
         self._padding = Padding.unpack(padding)
         self.pad_edge = pad_edge
-        self.expand = expand
+        self._expand = expand
         self.show_header = show_header
         self.show_footer = show_footer
         self.show_edge = show_edge
@@ -197,6 +196,16 @@ class Table(JupyterMixin):
             pad_edge=pad_edge,
         )
 
+    @property
+    def expand(self) -> int:
+        """Setting a non-None self.width implies expand."""
+        return self._expand or self.width is not None
+
+    @expand.setter
+    def expand(self, expand: bool) -> None:
+        """Set expand."""
+        self._expand = expand
+
     @property
     def _extra_width(self) -> int:
         """Get extra width to add to cell content."""
@@ -228,15 +237,20 @@ class Table(JupyterMixin):
                 max_width -= 2
 
         extra_width = self._extra_width
-        table_width = (
-            sum(self._calculate_column_widths(console, max_width)) + extra_width
-        )
         _measure_column = self._measure_column
-        minimum_width = max(
-            _measure_column(console, column, max_width).minimum
-            for column in self.columns
+
+        measurements = [
+            _measure_column(console, column, max_width) for column in self.columns
+        ]
+        minimum_width = (
+            sum(measurement.minimum for measurement in measurements) + extra_width
         )
-        return Measurement(minimum_width, table_width)
+        maximum_width = (
+            sum(measurement.maximum for measurement in measurements) + extra_width
+            if (self.width is None)
+            else self.width
+        )
+        return Measurement(minimum_width, maximum_width)
 
     @property
     def padding(self) -> Tuple[int, int, int, int]:
@@ -253,6 +267,7 @@ class Table(JupyterMixin):
         self,
         header: "RenderableType" = "",
         footer: "RenderableType" = "",
+        *,
         header_style: StyleType = None,
         footer_style: StyleType = None,
         style: StyleType = None,
@@ -297,18 +312,24 @@ class Table(JupyterMixin):
         )
         self.columns.append(column)
 
-    def add_row(self, *renderables: Optional["RenderableType"]) -> None:
+    def add_row(
+        self, *renderables: Optional["RenderableType"], style: StyleType = None
+    ) -> None:
         """Add a row of renderables.
         
         Args:
-            *renderables (None or renderable): Each cell in a row must be None (for a blank cell) or a renderable object (including str).
+            *renderables (None or renderable): Each cell in a row must be a renderable object (including str),
+                or ``None`` for a blank cell.
+            style (StyleType, optional): An optional style to apply to the entire row. Defaults to None.
 
         Raises:
             errors.NotRenderableError: If you add something that can't be rendered.
         """
 
         def add_cell(column: Column, renderable: "RenderableType") -> None:
-            column._cells.append(renderable)
+            column._cells.append(
+                renderable if style is None else Styled(renderable, style)
+            )
 
         cell_renderables: List[Optional["RenderableType"]] = list(renderables)
 
@@ -350,22 +371,23 @@ class Table(JupyterMixin):
         widths = self._calculate_column_widths(console, max_width)
         table_width = sum(widths) + self._extra_width
 
-        def render_annotation(
-            text: Union[Text, str], style: Union[str, Style]
-        ) -> "Lines":
-            if isinstance(text, Text):
-                render_text = text
-            else:
-                render_text = console.render_str(text, style=style)
-            return render_text.wrap(console, table_width, justify="center")
+        render_options = options.update(width=table_width)
+
+        def render_annotation(text: TextType, style: StyleType) -> "RenderResult":
+            render_text = (
+                console.render_str(text, style=style) if isinstance(text, str) else text
+            )
+            return console.render(
+                render_text, options=render_options.update(justify="center")
+            )
 
         if self.title:
-            yield render_annotation(
+            yield from render_annotation(
                 self.title, style=Style.pick_first(self.title_style, "table.title")
             )
-        yield from self._render(console, options, widths)
+        yield from self._render(console, render_options, widths)
         if self.caption:
-            yield render_annotation(
+            yield from render_annotation(
                 self.caption,
                 style=Style.pick_first(self.caption_style, "table.caption"),
             )
@@ -422,6 +444,18 @@ class Table(JupyterMixin):
             )
             table_width = sum(widths)
 
+        # Reduce columns again
+        if table_width > max_width:
+            excess_width = table_width - max_width
+            widths = ratio_reduce(
+                excess_width,
+                [0 if column.no_wrap else 1 for column in columns],
+                [width_range.maximum for width_range in width_ranges],
+                widths,
+            )
+            table_width = sum(widths)
+
+        # last resort, reduce columns evenly
         if table_width > max_width:
             excess_width = table_width - max_width
             widths = ratio_reduce(
@@ -485,12 +519,12 @@ class Table(JupyterMixin):
         for first, last, (style, renderable) in loop_first_last(raw_cells):
             yield _Cell(style, add_padding(renderable, first, last))
 
-    def _get_padding_width(self, column_index) -> int:
+    def _get_padding_width(self, column_index: int) -> int:
         """Get extra width from padding."""
         _, pad_right, _, pad_left = self.padding
         if self.collapse_padding:
-            if column_index != 0:
-                pad_left = max(0, pad_right - pad_left)
+            if column_index > 0:
+                pad_left = max(0, pad_left - pad_right)
         return pad_left + pad_right
 
     def _measure_column(
@@ -535,9 +569,13 @@ class Table(JupyterMixin):
                 )
             )
         )
-        _box: Optional[box.Box] = (
-            box.SQUARE if (console.legacy_windows and self.box) else self.box
+        _box = (
+            box.get_safe_box(self.box, console.legacy_windows)
+            if self.safe_box
+            else self.box
         )
+
+        # _box = self.box
         new_line = Segment.line()
 
         columns = self.columns
@@ -555,7 +593,7 @@ class Table(JupyterMixin):
                     _Segment(_box.head_vertical, border_style),
                 ),
                 (
-                    Segment(_box.foot_left, border_style),
+                    _Segment(_box.foot_left, border_style),
                     _Segment(_box.foot_right, border_style),
                     _Segment(_box.foot_vertical, border_style),
                 ),
@@ -566,7 +604,7 @@ class Table(JupyterMixin):
                 ),
             ]
             if show_edge:
-                yield Segment(_box.get_top(widths), border_style)
+                yield _Segment(_box.get_top(widths), border_style)
                 yield new_line
         else:
             box_segments = []
@@ -674,7 +712,6 @@ if __name__ == "__main__":  # pragma: no cover
     table.add_row(
         "Magnet",
         "pneumonoultramicroscopicsilicovolcanoconiosispneumonoultramicroscopicsilicovolcanoconiosispneumonoultramicroscopicsilicovolcanoconiosis",
-        "foo",
     )
     table.add_row(
         "Magnet",
